builder property

WidgetBuilder builder
latefinal

The widget tree that is affected handled by the DeviceSimulator, typically this is your whole app except the top App widget.

Implementation

late final WidgetBuilder builder;