enable property
Enables or disables the DeviceSimulator, default is enabled, but this should be set to false in production.
Implementation
final bool enable;
Enables or disables the DeviceSimulator, default is enabled, but this should be set to false in production.
final bool enable;