DeviceSpecification class
Constructors
-
DeviceSpecification({required String name, required Size size, required EdgeInsets padding, required TargetPlatform platform, EdgeInsets? paddingLandscape, double cornerRadius = 0.0, Size? notchSize, bool tablet = false, double navBarHeight = 48.0})
-
-
DeviceSpecification.fromPixel({required double height, required double width, required double pixelRatio, required EdgeInsets padding, EdgeInsets? paddingLandscape, required String name, double cornerRadius = 0.0, Size? notchSize, bool tablet = false, double navBarHeight = 48, required TargetPlatform platform})
-
factory
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited