DeviceSimulator class
Add the DeviceSimulator at the root of your widget tree, right below your App widget. DeviceSimulator will override the devices MediaQueryData and draw simulated device frames for different devices. It will also simulate the iOS or Android status bars (and on Android bottom navigation). You can disable the DeviceSimulator by setting the enable property to false.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DeviceSimulator
Constructors
- DeviceSimulator({required WidgetBuilder builder, bool enable = true, Brightness brightness = Brightness.light, Color iOSMultitaskBarColor = Colors.grey, Color androidStatusBarBackgroundColor = Colors.black26, Orientation? orientation, int initialDeviceIndex = 0, TargetPlatform initialPlatform = TargetPlatform.android, Color? backgroundColor, bool showBottomBar = true, bool showDeviceSlider = true})
- Creates a new DeviceSimulator.
Properties
-
Visibility of the bottom Android navigation bar (default is visible).
final
- androidStatusBarBackgroundColor → Color
-
The color of the top Android status bar (default is transparent black).
final
- backgroundColor → Color
-
final
- brightness → Brightness
-
The brightness decides how to draw the status bar (black or white).
final
- builder ↔ WidgetBuilder
-
The widget tree that is affected handled by the DeviceSimulator,
typically this is your whole app except the top
Appwidget.latefinal - enable → bool
-
Enables or disables the DeviceSimulator, default is enabled, but this
should be set to false in production.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialDeviceIndex → int
-
final
- initialPlatform → TargetPlatform
-
final
- iOSMultitaskBarColor → Color
-
The color of the iOS multitasking bar that is available on newer
iOS devices without a home button.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- orientation → Orientation?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showBottomBar → bool
-
final
- showDeviceSlider → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → _DeviceSimulatorState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- mediaQueryData ↔ MediaQueryData
-
getter/setter pair