builder property
The widget tree that is affected handled by the DeviceSimulator,
typically this is your whole app except the top App widget.
Implementation
late final WidgetBuilder builder;
The widget tree that is affected handled by the DeviceSimulator,
typically this is your whole app except the top App widget.
late final WidgetBuilder builder;